Provides extra functions to manipulate dendrograms that build on the base functions provided by the 'stats' package. The main functionality it is designed to add is the ability to colour all the edges in an object of class 'dendrogram' according to cluster membership i.e. each subtree is coloured, not just the terminal leaves. In addition it provides some utility functions to cut 'dendrogram' and 'hclust' objects and to set/get labels.
dendroextras provides the slice function as an
alternative to the base cut function. In contrast to
cut, slice returns group membership in dendrogram
order i.e. the first element in the group vector that is returned will be
the leftmost member of the leftmost cluster (cluster #1).
dendroextras provides colour_clusters to colour all of
the edges forming clusters cut by height or number of groups. You can also
set and retrieve the leaf colours (i.e. the terminal nodes) using
set_leaf_colours and leaf_colours.
dendroextras provides labels and
labels<- methods to get and set the labels of cluster
members.
Maintainer: Gregory Jefferis jefferis@gmail.com
Authors:
Gregory Jefferis jefferis@gmail.com
dendrogram, hclust in stats
package.